Learn R Programming

vctrs (version 0.3.8)

vctrs-package: vctrs: Vector Helpers

Description

[Maturing]

Defines new notions of prototype and size that are used to provide tools for consistent and well-founded type-coercion and size-recycling, and are in turn connected to ideas of type- and size-stability useful for analysing function interfaces.

Arguments

See Also

Useful links: