powered by
Defines new notions of prototype and size that are used to provide tools for consistent and well-founded type-coercion and size-recycling, and are in turn connected to ideas of type- and size-stability useful for analysing function interfaces.
Useful links:
https://vctrs.r-lib.org/
Report bugs at https://github.com/r-lib/vctrs/issues